@@ -5,7 +5,6 @@ use strict;
 use Carp;
 use warnings::register;
 use IO::Handle; # allow method calls on filehandles on older Perls
-use Hash::Util qw/lock_ref_keys/; # typo prevention
 use File::Temp qw/tempfile/;
 use File::Basename qw/fileparse/;
 use File::Spec::Functions qw/devnull/;
@@ -14,12 +13,24 @@ use Fcntl qw/S_IMODE/;
 use Exporter 'import';
 use File::Replace::SingleHandle ();
 use File::Replace::DualHandle ();
+BEGIN {
+	require Hash::Util;
+	# apparently this wasn't available until 0.06 / Perl 5.8.9
+	# since this is just for internal typo prevention,
+	# we can fake it when it's not available
+	# uncoverable branch false
+	# uncoverable condition right
+	# uncoverable condition false
+	if ($] ge '5.010' || defined &Hash::Util::lock_ref_keys)
+		{ Hash::Util->import('lock_ref_keys') }
+	else { *lock_ref_keys = sub {} }  # uncoverable statement
+}
 
 # For AUTHOR, COPYRIGHT, AND LICENSE see the bottom of this file
 
 ## no critic (RequireArgUnpacking)
 
-our $VERSION = '0.02';
+our $VERSION = '0.04';
 
 our @EXPORT_OK = qw/ replace replace2 /;
 our @CARP_NOT = qw/ File::Replace::SingleHandle File::Replace::DualHandle /;
@@ -257,7 +268,7 @@ documentation and search the Internet for "atomic rename" for more details.
 
 =head2 Version
 
-This documentation describes version 0.02 of this module.
+This documentation describes version 0.04 of this module.
 
 B<This is an alpha version.> While the module works and has a full test suite,
 I may still decide to change the API as I gain experience with it. I will try
